==> django-toggle-switch-widget-0.1.1.tar.gz: django-toggle-switch-widget-0.1.1/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-toggle-switch-widget",
    version="0.1.1",
    description="Display toggle switch in stead of checkbox for BooleanField in django admin site.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="zencore",
    author_email="dobetter@zencore.cn",
    url="https://github.com/zencore-cn/zencore-issues",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django toggle switch widget"],
    install_requires=requires,
    packages=find_packages(".", exclude=["django_toggle_switch_widget_example", "django_toggle_switch_widget_example.migrations", "django_toggle_switch_widget_demo"]),
    py_modules=["django_toggle_switch_widget"],
    zip_safe=False,
    include_package_data=True,
)

==> django-toggle-switch-widget-0.1.3.tar.gz: django-toggle-switch-widget-0.1.3/setup.py <==
# -*- coding: utf-8 -*-
import os
from io import open
from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))

with open(os.path.join(here, "README.md"), "r", encoding="utf-8") as fobj:
    long_description = fobj.read()

with open(os.path.join(here, "requirements.txt"), "r", encoding="utf-8") as fobj:
    requires = [x.strip() for x in fobj.readlines() if x.strip()]

setup(
    name="django-toggle-switch-widget",
    version="0.1.3",
    description="Display toggle switch in stead of checkbox for BooleanField in django admin site.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Zhou Wen",
    author_email="zhouwen@zencore.cn",
    maintainer="Zhou Wen",
    maintainer_email="zhouwen@zencore.cn",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords=["django admin extentions", "django toggle switch widget"],
    install_requires=requires,
    packages=find_packages(
        ".",
        exclude=[
            "django_toggle_switch_widget_example",
            "django_toggle_switch_widget_example.migrations",
            "django_toggle_switch_widget_demo",
        ],
    ),
    py_modules=["django_toggle_switch_widget"],
    zip_safe=False,
    include_package_data=True,
)
